<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Content extends Admin_Controller
{

    public function __construct()
    {
        parent::__construct();
        $this->load->model('content_model');
    }

    public function index()
    {
        // check access permission
        if (!get_permission('manage_page', 'is_view')) {
            access_denied();
        }
        if ($_POST) {
            if (!get_permission('manage_page', 'is_add')) {
                access_denied();
            }
            $this->content_validation();
            if ($this->form_validation->run() == false) {
                $this->data['validation_error'] = true;
            } else {
                // save information in the database
                $arrayData = array(
                    'page_title' => $this->input->post('title'),
                    'menu_id' => $this->input->post('menu_id'),
                    'content' => $this->input->post('content', false),
                    'banner_image' => $this->content_model->uploadBanner('page_' . $this->input->post('menu_id'), 'banners'),
                    'meta_description' => $this->input->post('meta_description'),
                    'meta_keyword' => $this->input->post('meta_keyword'),
                );
                $this->content_model->save_content($arrayData);
                set_alert('success', translate('information_has_been_saved_successfully'));
                redirect(base_url('frontend/content'));
            }
        }
        $this->data['headerelements'] = array(
            'js' => array(
                'vendor/ckeditor/ckeditor.js',
            ),
        );
        $this->data['pagelist'] = $this->content_model->get_page_list();
        $this->data['title'] = translate('frontend');
        $this->data['sub_page'] = 'frontend/content';
        $this->data['main_menu'] = 'frontend';
        $this->load->view('layout/index', $this->data);
    }

    public function edit($id = '')
    {
        if (!get_permission('manage_page', 'is_edit')) {
            access_denied();
        }
        if ($this->input->post()) {
            $this->content_validation();
            if ($this->form_validation->run() == false) {
                $this->data['validation_error'] = true;
            } else {
                // update information in the database
                $page_id = $this->input->post('page_id');
                $arrayData = array(
                    'page_title' => $this->input->post('title'),
                    'menu_id' => $this->input->post('menu_id'),
                    'content' => $this->input->post('content', false),
                    'banner_image' => $this->content_model->uploadBanner('page_' . $this->input->post('menu_id'), 'banners'),
                    'meta_description' => $this->input->post('meta_description'),
                    'meta_keyword' => $this->input->post('meta_keyword'),
                );
                $this->content_model->save_content($arrayData, $page_id);
                set_alert('success', translate('information_has_been_updated_successfully'));
                redirect(base_url('frontend/content'));
            }
        }
        
        $this->data['headerelements'] = array(
            'js' => array(
                'vendor/ckeditor/ckeditor.js',
            ),
        );
        $this->data['content'] = $this->content_model->get_list('front_cms_pages', array('id' => $id), true);
        $this->data['title'] = translate('frontend');
        $this->data['sub_page'] = 'frontend/content_edit';
        $this->data['main_menu'] = 'frontend';
        $this->load->view('layout/index', $this->data);
    }

    public function delete($id = '')
    {
        if (!get_permission('manage_page', 'is_delete')) {
            access_denied();
        }
        $this->db->where(array('id' => $id))->delete("front_cms_pages");
    }

    private function content_validation()
    {
        $this->form_validation->set_rules('title', 'Page Title', 'trim|required|xss_clean');
        $this->form_validation->set_rules('menu_id', 'Select Menu', 'trim|required|xss_clean|callback_unique_menu');
        $this->form_validation->set_rules('content', 'Content', 'required');
        $this->form_validation->set_rules('meta_keyword', 'Meta Keyword', 'xss_clean');
        $this->form_validation->set_rules('photo', 'Photo', 'trim|xss_clean|callback_check_image');
        $this->form_validation->set_rules('meta_description', 'Meta Description', 'xss_clean');
    }

    public function check_image()
    {
        $prev_image = $this->input->post('old_photo');
        if ($prev_image == "") {
            if (isset($_FILES['photo']['name']) && !empty($_FILES['photo']['name'])) {
                $name = $_FILES['photo']['name'];
                $arr = explode('.', $name);
                $ext = end($arr);
                if ($ext == 'jpg' || $ext == 'jpeg' || $ext == 'png') {
                    return true;
                } else {
                    $this->form_validation->set_message('check_image', translate('select_valid_file_format'));
                    return false;
                }
            } else {
                $this->form_validation->set_message('check_image', 'The Photo is required.');
                return false;
            }
        } else {
            return true;
        }
    }

    // unique valid menu verification is done here
    public function unique_menu($id)
    {
        if ($this->input->post('page_id')) {
            $page_id = $this->input->post('page_id');
            $this->db->where_not_in('id', $page_id);
        }
        $this->db->where('menu_id', $id);
        $query = $this->db->get('front_cms_pages');
        if ($query->num_rows() > 0) {
            $this->form_validation->set_message("unique_menu", "This menu has already been allocated.");
            return false;
        } else {
            return true;
        }
    }
    
     public function vision_mission()
    {
        // check access permission
        if (!get_permission('manage_page', 'is_view')) {
            access_denied();
        }
        if ($_POST) {
                $seo_content['page_title'] = $this->input->post('page_title');
                $seo_content['meta_keyword'] = $this->input->post('meta_keyword');
                $seo_content['meta_description'] = $this->input->post('meta_description');
                $seo_content['news_keywords'] = $this->input->post('news_keywords');
                $seo_content['meta_abstract'] = $this->input->post('abstract');
                $seo_content['dc_source'] = $this->input->post('dc_source');
                $seo_content['dc_title'] = $this->input->post('dc_title');
                $seo_content['dc_keywords'] = $this->input->post('dc_keywords');
                $seo_content['dc_description'] = $this->input->post('dc_description');
                $seo_content['canonical'] = $this->input->post('canonical');
                $seo_content['alternate'] = $this->input->post('alternate');
                $seo_content['robot'] = $this->input->post('robot');
                $seo_content['copyright'] = $this->input->post('copyright');
                $seo_content['author'] = $this->input->post('author');
                $seo_content['og_locale'] = $this->input->post('og_locale');
                $seo_content['og_type'] = $this->input->post('og_type');
                $seo_content['og_title'] = $this->input->post('og_title');
                $seo_content['og_description'] = $this->input->post('og_description');
                $seo_content['og_url'] = $this->input->post('og_url');
                $seo_content['og_site_name'] = $this->input->post('og_site_name');
                $seo_content['og_image'] = $this->input->post('og_image');
                $seo_content['fb_admins'] = $this->input->post('fb_admins');
                $seo_content['twitter_card'] = $this->input->post('twitter_card');
                $seo_content['twitter_site'] = $this->input->post('twitter_site');
                $seo_content['twitter_creator'] = $this->input->post('twitter_creator');
                $seo_content['twitter_title'] = $this->input->post('twitter_title');
                $seo_content['twitter_description'] = $this->input->post('twitter_description');
                $seo_content['twitter_image_src'] = $this->input->post('twitter_image_src');
                $seo_content['twitter_canonical'] = $this->input->post('twitter_canonical');
                $seo_content['item_type'] = $this->input->post('item_type');
                $seo_content['item_name'] = $this->input->post('item_name');
                $seo_content['item_description'] = $this->input->post('item_description');
                $seo_content['item_url'] = $this->input->post('item_url');
                $seo_content['item_image'] = $this->input->post('item_image');
                $seo_content['item_author'] = $this->input->post('item_author');
                $seo_content['item_organization'] = $this->input->post('item_organization');
                $data = array(
                    'page_title' => $this->input->post('title'),
                    'vision' => $this->input->post('vision'),
                     'mission' => $this->input->post('mission'),
                      'value' => $this->input->post('value'),
                   'meta_description' => $this->input->post('meta_description'),
                    'meta_keyword' => $this->input->post('meta_keyword'),
                    'seo_content' => json_encode($seo_content),
                );
                if (isset($_FILES['photo']) && $_FILES['photo']['name'] != "") {
                    $path_parts = pathinfo($_FILES["photo"]["name"]);
                    $extension = '.'.$path_parts['extension'];
                    $filename = time().uniqid().$extension;
                    move_uploaded_file($_FILES['photo']['tmp_name'], 'uploads/images/about_us/'.$filename);
                    $data['banner_image'] = 'uploads/images/about_us/'.$filename;
                }
                
             
                $this->db->where('id',1);
                $this->db->update('vision_mission',$data);
                set_alert('success', translate('information_has_been_saved_successfully'));
                redirect(base_url('frontend/content'));
            
        }
        $this->data['headerelements'] = array(
            'js' => array(
                'vendor/ckeditor/ckeditor.js',
            ),
        );
        $this->data['pagelist'] = $this->db->get_where('vision_mission',array('id'=>1))->row();
        $this->data['title'] = translate('frontend');
        $this->data['sub_page'] = 'frontend/vision_mission';
        $this->data['main_menu'] = 'frontend';
        $this->load->view('layout/index', $this->data);
    }
    
    public function about_us()
    {
        // check access permission
        if (!get_permission('manage_page', 'is_view')) {
            access_denied();
        }
        if ($_POST) {
                $seo_content['page_title'] = $this->input->post('page_title');
                $seo_content['meta_keyword'] = $this->input->post('meta_keyword');
                $seo_content['meta_description'] = $this->input->post('meta_description');
                $seo_content['news_keywords'] = $this->input->post('news_keywords');
                $seo_content['meta_abstract'] = $this->input->post('abstract');
                $seo_content['dc_source'] = $this->input->post('dc_source');
                $seo_content['dc_title'] = $this->input->post('dc_title');
                $seo_content['dc_keywords'] = $this->input->post('dc_keywords');
                $seo_content['dc_description'] = $this->input->post('dc_description');
                $seo_content['canonical'] = $this->input->post('canonical');
                $seo_content['alternate'] = $this->input->post('alternate');
                $seo_content['robot'] = $this->input->post('robot');
                $seo_content['copyright'] = $this->input->post('copyright');
                $seo_content['author'] = $this->input->post('author');
                $seo_content['og_locale'] = $this->input->post('og_locale');
                $seo_content['og_type'] = $this->input->post('og_type');
                $seo_content['og_title'] = $this->input->post('og_title');
                $seo_content['og_description'] = $this->input->post('og_description');
                $seo_content['og_url'] = $this->input->post('og_url');
                $seo_content['og_site_name'] = $this->input->post('og_site_name');
                $seo_content['og_image'] = $this->input->post('og_image');
                $seo_content['fb_admins'] = $this->input->post('fb_admins');
                $seo_content['twitter_card'] = $this->input->post('twitter_card');
                $seo_content['twitter_site'] = $this->input->post('twitter_site');
                $seo_content['twitter_creator'] = $this->input->post('twitter_creator');
                $seo_content['twitter_title'] = $this->input->post('twitter_title');
                $seo_content['twitter_description'] = $this->input->post('twitter_description');
                $seo_content['twitter_image_src'] = $this->input->post('twitter_image_src');
                $seo_content['twitter_canonical'] = $this->input->post('twitter_canonical');
                $seo_content['item_type'] = $this->input->post('item_type');
                $seo_content['item_name'] = $this->input->post('item_name');
                $seo_content['item_description'] = $this->input->post('item_description');
                $seo_content['item_url'] = $this->input->post('item_url');
                $seo_content['item_image'] = $this->input->post('item_image');
                $seo_content['item_author'] = $this->input->post('item_author');
                $seo_content['item_organization'] = $this->input->post('item_organization');
                $data = array(
                    'page_title' => $this->input->post('title'),
                    'content' => $this->input->post('content'),
                         'bellowcontent' => $this->input->post('bellowcontent'),
                   'meta_description' => $this->input->post('meta_description'),
                    'meta_keyword' => $this->input->post('meta_keyword'),
                    'seo_content' => json_encode($seo_content),
                );
                if (isset($_FILES['photo']) && $_FILES['photo']['name'] != "") {
                    $path_parts = pathinfo($_FILES["photo"]["name"]);
                    $extension = '.'.$path_parts['extension'];
                    $filename = time().uniqid().$extension;
                    move_uploaded_file($_FILES['photo']['tmp_name'], 'uploads/images/about_us/'.$filename);
                    $data['banner_image'] = 'uploads/images/about_us/'.$filename;
                }
                
             
                $this->db->where('id',1);
                $this->db->update('about_us',$data);
                set_alert('success', translate('information_has_been_saved_successfully'));
                redirect(base_url('frontend/content'));
            
        }
        $this->data['headerelements'] = array(
            'js' => array(
                'vendor/ckeditor/ckeditor.js',
            ),
        );
        $this->data['pagelist'] = $this->db->get_where('about_us',array('id'=>1))->row();
        $this->data['title'] = translate('frontend');
        $this->data['sub_page'] = 'frontend/about_us';
        $this->data['main_menu'] = 'frontend';
        $this->load->view('layout/index', $this->data);
    }






    
    function format_uri( $string, $separator = '-' ){
        $accents_regex = '~&([a-z]{1,2})(?:acute|cedil|circ|grave|lig|orn|ring|slash|th|tilde|uml);~i';
        $special_cases = array( '&' => 'and', "'" => '');
        $string = mb_strtolower( trim( $string ), 'UTF-8' );
        $string = str_replace( array_keys($special_cases), array_values( $special_cases), $string );
        $string = preg_replace( $accents_regex, '$1', htmlentities( $string, ENT_QUOTES, 'UTF-8' ) );
        $string = preg_replace("/[^a-z0-9]/u", "$separator", $string);
        $string = preg_replace("/[$separator]+/u", "$separator", $string);
        return $string;
    }
}
